/*
 * Copyright (c) 2002-2004
 * All rights reserved.
 */

package cern.jira.emailhandler;

import java.io.IOException;

import javax.mail.Message;
import javax.mail.MessagingException;
import javax.mail.Part;

import org.apache.log4j.Category;

import com.atlassian.jira.service.util.handler.AbstractCommentHandler;
import com.atlassian.mail.MailUtils;

public class FullCommentHandler extends AbstractCommentHandler
{
    private static final Category log = Category.getInstance(FullCommentHandler.class);

    /**
     * Given a message, adds the entire message body as a comment to
     * the first issue referenced in the subject.
     */
    protected String getEmailBody(Message message) throws MessagingException
    {
        return MailUtils.getBody(message);
    }

    /**
     * Attaches plaintext parts.  
     * Plain text parts must be kept if they are not empty.
     *
     * @param part  the plain text part.
     * @return  true if the part is not empty, false otherwise
     */
    protected boolean attachPlainTextParts(final Part part) throws MessagingException, IOException
    {
        return !MailUtils.isContentEmpty(part);
    }

    /**
     * Attaches HTML parts.
     * Comments never wish to keep html parts that are not attachments as they extract the plain text
     * part and use that as the content. This method therefore is hard wired to always return false.
     *
     * @param part  the HTML part being processed
     * @return  always false
     * @throws  MessagingException
     * @throws  IOException
     */
    protected boolean attachHtmlParts(final javax.mail.Part part) throws MessagingException, IOException
    {
        return false;
    }
}
